==> moodle_1.3.1.orig.tar.gz: moodle/lang/ko/glossary.php <==
<?PHP // $Id: glossary.php,v 1.1 2004/02/10 06:38:11 moodler Exp $ 
      // glossary.php - created with Moodle 1.2 development (2004013100)


$string['addcomment'] = ' ';
$string['addentry'] = ' ׸ ';
$string['addingcomment'] = ' ';
$string['aliases'] = '˻';
$string['allcategories'] = ' ';
$string['allentries'] = 'ü';
$string['allowcomments'] = ' ';
$string['allowduplicatedentries'] = ' ';
$string['allowratings'] = 'õ ';
$string['answer'] = '';
$string['approve'] = '';
$string['areyousuredelete'] = ' ׸ ?';
$string['areyousuredeletecomment'] = '  ?';
$string['areyousureexport'] = '?';
$string['ascending'] = '';
$string['attachment'] = '';
$string['authorview'] = '  ';
$string['back'] = 'ڷ';
$string['cantinsertcat'] = 'ָ ߰  ';
$string['cantinsertrec'] = 'ڷḦ ߰  ';
$string['cantinsertrel'] = ' ׸ 踦   ';
$string['casesensitive'] = '빮, ҹڸ ϼ';
$string['categories'] = ' ׸';
$string['category'] = '';
$string['categorydeleted'] = ' ';
$string['categoryview'] = 'ֺ ';
$string['cnfallowcomments'] = 'ڷ ׸鿡  ޱ  ⺻   ϼ.';
$string['cnfallowdupentries'] = 'ڷ  ׸  ⺻   ϼ.';
$string['cnfapprovalstatus'] = 'л ø  ⺻   ϼ.';
$string['cnfcasesensitive'] = ' ũ ׸ ִٸ ,ҹڸ ϴ  ⺻ ұ?';
$string['cnfdefaulthook'] = 'ڷ ó   ⺻  ׸ ϼ.';
$string['cnfdefaultmode'] = 'ڷ ó   ⺻  ϼ.';
$string['cnffullmatch'] = ' ũ ׸ ִٸ ⺻  ҹڿ ġϵ ұ?';
$string['cnflinkentry'] = '׸ ڵ ũǵ ⺻ ұ?';
$string['cnflinkglossaries'] = 'ڷ ڷ ũǵ ⺻ ұ?';
$string['cnfrelatedview'] = 'ڵ ũ ׸ ⿡ Ǵ ǥ  ϼ.';
$string['cnfshowgroup'] = '׷ ̵ ұ?';
$string['cnfsortkey'] = '⺻  Ű ϼ.';
$string['cnfsortorder'] = '⺻   ϼ.';
$string['cnfstudentcanpost'] = '⺻ л  ø  ֵ ұ, ø   ұ?';
$string['comment'] = '';
$string['commentdeleted'] = ' Ǿϴ.';
$string['comments'] = '';
$string['commentson'] = '';
$string['commentupdated'] = ' ߰Ǿϴ.';
$string['concept'] = '';
$string['concepts'] = '';
$string['currentglossary'] = ' ڷ';
$string['dateview'] = '¥ ';
$string['defaultapproval'] = '  ⺻';
$string['definition'] = '';
$string['definitions'] = '';
$string['deleteentry'] = '׸ ';
$string['deletingcomment'] = ' ';
$string['deletingnoneemptycategory'] = ' ָ ص ֳ ۵  ʽϴ.  ۵   ǥõ Դϴ.';
$string['descending'] = '';
$string['destination'] = '';
$string['displayformat'] = ' ';
$string['displayformat2'] = 'ü - ø';
$string['displayformat3'] = '';
$string['displayformat4'] = 'FAQ';
$string['displayformat5'] = 'ü- ø ';
$string['displayformat6'] = '׸';
$string['displayformatcontinuous'] = 'ø̾ ̾';
$string['displayformatdefault'] = 'ó';
$string['displayformats'] = ' ';
$string['duplicateentry'] = '׸ ';
$string['editcategories'] = ' ';
$string['editentry'] = '׸ ';
$string['editingcomment'] = ' ';
$string['entbypage'] = 'ʴ ׸';
$string['entries'] = '׸';
$string['entrieswithoutcategory'] = '  ׸';
$string['entry'] = '׸';
$string['entryalreadyexist'] = '̹ ϴ ׸';
$string['entryapproved'] = ' ׸ ε';
$string['entrydeleted'] = '׸ ';
$string['entryexported'] = '׸  ';
$string['entryishidden'] = '( ׸  )';
$string['entryusedynalink'] = '׸ ڵ ũ';
$string['explainaddentry'] = ' ڷ  ׸ ߰մϴ.';
$string['explainall'] = ' ʿ  ׸ ';
$string['explainalphabet'] = ' Ͽ ڷ ';
$string['explainexport'] = ' Ǿϴ.  ٿ޾ ϰ ϼ. ̰ ٸ Ϳ ٽ   ֽϴ.';
$string['explainimport'] = '   ü  մϴ. ׸  ָ մϴ.

';
$string['explainspecial'] = 'ڷ  ʴ ׸ ';
$string['exportedentry'] = ' ׸';
$string['exportedfile'] = ' ';
$string['exportentries'] = '׸ ';
$string['exportglossary'] = 'ڷ ';
$string['exporttomainglossary'] = ' ڷ ';
$string['filetoimport'] = ' ';
$string['fillfields'] = 'ʼ ä־ ϴ ׸';
$string['fullmatch'] = ' ġϴ ܾ';
$string['glossarytype'] = 'ڷ ';
$string['glosssaryexported'] = 'ڷ ';
$string['importcategories'] = '׸ ';
$string['importedcategories'] = '  ';
$string['importedentries'] = '  ׸';
$string['importentries'] = '׸ ';
$string['isglobal'] = ' ڷ ΰ?';
$string['linkcategory'] = ' ַ ڵ ũ';
$string['mainglossary'] = 'ֵ ڷ';
$string['maxtimehaspassed'] = '˼մϴٸ,   ִ Ƚ($a) ʰϿϴ!';
$string['modulename'] = 'ڷ';
$string['modulenameplural'] = 'ڷ';
$string['newentries'] = 'ο ڷ ׸';
$string['newglossary'] = 'ο ڷ';
$string['newglossarycreated'] = 'ο ڷ ';
$string['newglossaryentries'] = 'ο ڷ ׸:';
$string['nocomment'] = ' ';
$string['nocomments'] = '(۾)';
$string['noconceptfound'] = 'ǵ ';
$string['noentries'] = ' 翡 ߰ߵ ׸ ';
$string['noentry'] = '׸ ';
$string['notcategorised'] = '  ';
$string['numberofentries'] = '׸ ';
$string['onebyline'] = '( ٿ ϳ)';
$string['printerfriendly'] = 'μ ';
$string['question'] = '';
$string['rate'] = 'õ';
$string['rating'] = 'õϱ';
$string['ratingeveryone'] = ' õ ';
$string['ratingno'] = 'õ ';
$string['ratingonlyteachers'] = ' $a  õ  ';
$string['ratings'] = 'õ';
$string['ratingssaved'] = 'õ ';
$string['ratingsuse'] = 'õ ';
$string['ratingtime'] = 'Ʒ  Ⱓ ׸ õ  ֵ մϴ:';
$string['rejectedentries'] = 'ݼ۵ ׸';
$string['rejectionrpt'] = 'ݼ ';
$string['searchindefinition'] = ' ˻';
$string['secondaryglossary'] = ' ڷ';
$string['sendinratings'] = ' ֱ õ ּ';
$string['showall'] = '\'\'ũ ';
$string['showalphabet'] = 'öڼ ';
$string['showspecial'] = '\'Ư\' ũ ';
$string['sortby'] = 'з';
$string['sortbycreation'] = ' ';
$string['sortbylastupdate'] = '  ';
$string['sortchronogically'] = 'ǥ  ';
$string['special'] = 'Ư';
$string['standardview'] = ' ';
$string['studentcanpost'] = 'л ׸ ߰  ';
$string['totalentries'] = 'ü ׸';
$string['usedynalink'] = 'ڷ ׸ ڵ ũ';
$string['waitingapproval'] = '  ';
$string['warningstudentcapost'] = '(ڷ  ڷ ƴҶ ϼ)';
$string['writtenby'] = 'ø:';
$string['youarenottheauthor'] = '    ĥ  ֽϴ.';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/ko/glossary.php <==
<?PHP // $Id$ 
      // glossary.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['addcomment'] = ' ';
$string['addentry'] = ' ׸ ';
$string['addingcomment'] = ' ';
$string['aliases'] = '˻';
$string['allcategories'] = ' ';
$string['allentries'] = 'ü';
$string['allowcomments'] = ' ';
$string['allowduplicatedentries'] = ' ';
$string['allowratings'] = 'õ ';
$string['answer'] = '';
$string['approve'] = '';
$string['areyousuredelete'] = ' ׸ ?';
$string['areyousuredeletecomment'] = '  ?';
$string['areyousureexport'] = '?';
$string['ascending'] = '';
$string['attachment'] = '';
$string['authorview'] = '  ';
$string['back'] = 'ڷ';
$string['cantinsertcat'] = 'ָ ߰  ';
$string['cantinsertrec'] = 'ڷḦ ߰  ';
$string['cantinsertrel'] = ' ׸ 踦   ';
$string['casesensitive'] = '빮, ҹڸ ϼ';
$string['categories'] = ' ׸';
$string['category'] = '';
$string['categorydeleted'] = ' ';
$string['categoryview'] = 'ֺ ';
$string['cnfallowcomments'] = 'ڷ ׸鿡  ޱ  ⺻   ϼ.';
$string['cnfallowdupentries'] = 'ڷ  ׸  ⺻   ϼ.';
$string['cnfapprovalstatus'] = 'л ø  ⺻   ϼ.';
$string['cnfcasesensitive'] = ' ũ ׸ ִٸ ,ҹڸ ϴ  ⺻ ұ?';
$string['cnfdefaulthook'] = 'ڷ ó   ⺻  ׸ ϼ.';
$string['cnfdefaultmode'] = 'ڷ ó   ⺻  ϼ.';
$string['cnffullmatch'] = ' ũ ׸ ִٸ ⺻  ҹڿ ġϵ ұ?';
$string['cnflinkentry'] = '׸ ڵ ũǵ ⺻ ұ?';
$string['cnflinkglossaries'] = 'ڷ ڷ ũǵ ⺻ ұ?';
$string['cnfrelatedview'] = 'ڵ ũ ׸ ⿡ Ǵ ǥ  ϼ.';
$string['cnfshowgroup'] = '׷ ̵ ұ?';
$string['cnfsortkey'] = '⺻  Ű ϼ.';
$string['cnfsortorder'] = '⺻   ϼ.';
$string['cnfstudentcanpost'] = '⺻ л  ø  ֵ ұ, ø   ұ?';
$string['comment'] = '';
$string['commentdeleted'] = ' Ǿϴ.';
$string['comments'] = '';
$string['commentson'] = '';
$string['commentupdated'] = ' ߰Ǿϴ.';
$string['concept'] = '';
$string['concepts'] = '';
$string['currentglossary'] = ' ڷ';
$string['dateview'] = '¥ ';
$string['defaultapproval'] = '  ⺻';
$string['definition'] = '';
$string['definitions'] = '';
$string['deleteentry'] = '׸ ';
$string['deletingcomment'] = ' ';
$string['deletingnoneemptycategory'] = ' ָ ص ֳ ۵  ʽϴ.  ۵   ǥõ Դϴ.';
$string['descending'] = '';
$string['destination'] = '';
$string['displayformat'] = ' ';
$string['displayformatcontinuous'] = 'ø̾ ̾';
$string['displayformats'] = ' ';
$string['duplicateentry'] = '׸ ';
$string['editcategories'] = ' ';
$string['editentry'] = '׸ ';
$string['editingcomment'] = ' ';
$string['entbypage'] = 'ʴ ׸';
$string['entries'] = '׸';
$string['entrieswithoutcategory'] = '  ׸';
$string['entry'] = '׸';
$string['entryalreadyexist'] = '̹ ϴ ׸';
$string['entryapproved'] = ' ׸ ε';
$string['entrydeleted'] = '׸ ';
$string['entryexported'] = '׸  ';
$string['entryishidden'] = '( ׸  )';
$string['entryusedynalink'] = '׸ ڵ ũ';
$string['explainaddentry'] = ' ڷ  ׸ ߰մϴ.';
$string['explainall'] = ' ʿ  ׸ ';
$string['explainalphabet'] = ' Ͽ ڷ ';
$string['explainexport'] = ' Ǿϴ.  ٿ޾ ϰ ϼ. ̰ ٸ Ϳ ٽ   ֽϴ.';
$string['explainimport'] = '   ü  մϴ. ׸  ָ մϴ.';
$string['explainspecial'] = 'ڷ  ʴ ׸ ';
$string['exportedentry'] = ' ׸';
$string['exportedfile'] = ' ';
$string['exportentries'] = '׸ ';
$string['exportglossary'] = 'ڷ ';
$string['exporttomainglossary'] = ' ڷ ';
$string['filetoimport'] = ' ';
$string['fillfields'] = 'ʼ ä־ ϴ ׸';
$string['filtername'] = '۷μ ڵ ũ';
$string['fullmatch'] = ' ġϴ ܾ';
$string['glossarytype'] = 'ڷ ';
$string['glosssaryexported'] = 'ڷ ';
$string['importcategories'] = '׸ ';
$string['importedcategories'] = '  ';
$string['importedentries'] = '  ׸';
$string['importentries'] = '׸ ';
$string['isglobal'] = ' ڷ ΰ?';
$string['linkcategory'] = ' ַ ڵ ũ';
$string['mainglossary'] = 'ֵ ڷ';
$string['maxtimehaspassed'] = '˼մϴٸ,   ִ Ƚ($a) ʰϿϴ!';
$string['modulename'] = 'ڷ';
$string['modulenameplural'] = 'ڷ';
$string['newentries'] = 'ο ڷ ׸';
$string['newglossary'] = 'ο ڷ';
$string['newglossarycreated'] = 'ο ڷ ';
$string['newglossaryentries'] = 'ο ڷ ׸:';
$string['nocomment'] = ' ';
$string['nocomments'] = '(۾)';
$string['noconceptfound'] = 'ǵ ';
$string['noentries'] = ' 翡 ߰ߵ ׸ ';
$string['noentry'] = '׸ ';
$string['notcategorised'] = '  ';
$string['numberofentries'] = '׸ ';
$string['onebyline'] = '( ٿ ϳ)';
$string['printerfriendly'] = 'μ ';
$string['question'] = '';
$string['rate'] = 'õ';
$string['rating'] = 'õϱ';
$string['ratingeveryone'] = ' õ ';
$string['ratingno'] = 'õ ';
$string['ratingonlyteachers'] = ' $a  õ  ';
$string['ratings'] = 'õ';
$string['ratingssaved'] = 'õ ';
$string['ratingsuse'] = 'õ ';
$string['ratingtime'] = 'Ʒ  Ⱓ ׸ õ  ֵ մϴ:';
$string['rejectedentries'] = 'ݼ۵ ׸';
$string['rejectionrpt'] = 'ݼ ';
$string['searchindefinition'] = ' ˻';
$string['secondaryglossary'] = ' ڷ';
$string['sendinratings'] = ' ֱ õ ּ';
$string['showall'] = '\'\'ũ ';
$string['showalphabet'] = 'öڼ ';
$string['showspecial'] = '\'Ư\' ũ ';
$string['sortby'] = 'з';
$string['sortbycreation'] = ' ';
$string['sortbylastupdate'] = '  ';
$string['sortchronogically'] = 'ǥ  ';
$string['special'] = 'Ư';
$string['standardview'] = ' ';
$string['studentcanpost'] = 'л ׸ ߰  ';
$string['thischarset'] = 'euc-kr';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = '&#54620;&#44397;&#50612;';
$string['totalentries'] = 'ü ׸';
$string['usedynalink'] = 'ڷ ׸ ڵ ũ';
$string['waitingapproval'] = '  ';
$string['warningstudentcapost'] = '(ڷ  ڷ ƴҶ ϼ)';
$string['writtenby'] = 'ø:';
$string['youarenottheauthor'] = '    ĥ  ֽϴ.';

?>
